import { csv, select } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/MeghanaChowdaryKomatineni/e4d4fc442e44f6bafdfa6f87b8b0bdce/raw/32038fcc0a00970dcf19ae1fad749850c2b1dc38/iris.csv';

const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const main = async () => {
  // Load the dataset
  const data = await csv(csvUrl, parseRow);

  // Extract the sepal length and sepal width data
  const sepalData = data.map((d) => ({
    sepal_length: d.sepal_length,
    sepal_width: d.sepal_width,
  }));

  // Set up the SVG canvas dimensions
  const margin = {
    top: 20,
    right: 20,
    bottom: 30,
    left: 50,
  };
  const width = 600 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  // Append the SVG canvas to the body of the webpage
  const svg = select('body')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Set up the X and Y scales
  const xScale = d3.scaleLinear().range([0, width]);
  const yScale = d3.scaleLinear().range([height, 0]);

  // Define the area function
  const area = d3
    .area()
    .x((d) => xScale(d.sepal_length))
    .y1((d) => yScale(d.sepal_width));

  // Set the domain of the X and Y scales
  xScale.domain(
    d3.extent(sepalData, (d) => d.sepal_length),
  );
  yScale.domain([
    0,
    d3.max(sepalData, (d) => d.sepal_width),
  ]);

  // Add the area path to the SVG canvas
  svg
    .append('path')
    .datum(sepalData)
    .attr('fill', 'steelblue')
    .attr('d', area);

  // Add the X Axis
  svg
    .append('g')
    .attr('transform', `translate(0, ${height})`)
    .call(d3.axisBottom(xScale));

  // Add the Y Axis
  svg.append('g').call(d3.axisLeft(yScale));

  // Add X-axis label
  svg
    .append('text')
    .attr(
      'transform',
      `translate(${width / 2}, ${height + margin.top + 10})`,
    )
    .style('text-anchor', 'middle')
    .text('Sepal Length');

  // Add Y-axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 0 - margin.left)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Sepal Width');
};

main();
